@@ -15,7 +15,7 @@ use List::MoreUtils qw( all zip );
 use List::Util qw( max min );
 use List::Util::WeightedChoice qw( choose_weighted );
 
-our $VERSION = '0.2004';
+our $VERSION = '0.2005';
 
 
 
@@ -504,7 +504,7 @@ Game::Theory::TwoPersonMatrix - Analyze a 2 person matrix game
 
 =head1 VERSION
 
-version 0.2004
+version 0.2005
 
 =head1 SYNOPSIS
 
@@ -602,8 +602,8 @@ Return the expected payoff value of a game.
 
 Return the expected payoff expression for a non-numeric game.
 
-Using real payoff values, we solve the resulting expression for p in the F<eg/>
-examples.
+Using real payoff values, we solve the resulting expression for B<p> in the
+F<eg/> examples.
 
 =head2 counter_strategy()
 
